==> libdclaf90-0.37.tar.gz: libdclaf90-0.37/manual/dcl_defval.f90 <==
module dcl_defval  ! DCL ѤΥ͡ꥹѿɬԲķ
  implicit none
!-- namelist values
  integer :: nx  ! ׻ΰ x γʻ
  integer :: ny  ! ׻ΰ y γʻ
  integer :: nz  ! ׻ΰ z γʻ
  real :: xmin  ! x η׻ΰ躸ü [m]
  real :: ymin  ! y η׻ΰü [m]
  real :: zmin  ! z η׻ΰ貼ü [m]
  real :: dx  ! x γʻҴֳ [m]
  real :: dy  ! y γʻҴֳ [m]
  real :: dz  ! z γʻҴֳ [m]
  integer :: dt  ! ׻ֳִ֡ʥץեδֳ֡ [s]
  integer :: fnumber  ! ɤ߹ե
  integer :: grd_rec  ! geography եѿο
  real :: cmin  ! ɤκǾ
  real :: cmax  ! ɤκ
  real :: contmin  ! κǾ
  real :: contmax  ! κ
  character(80) :: hname  ! ץեΥإå
  character(80) :: footname  ! ץեΥեå
  integer :: ininame  ! ץեɤ߹ߤ򳫻Ϥ [׻Ϥ s]
  character(80) :: grdname  ! geography ե̾
  character(80) :: title_name  ! դΥȥ̾ʸźǻ֤Ĥ
  integer :: shade_num  ! ɤʬ
  character(6) :: form_typec  ! Υեޥå
  character(6) :: form_types  ! ɤΥեޥå
  logical :: ldump  ! dcl Υ̿
  logical :: lwait  ! dcl ̿
  logical :: lwait1  ! dcl ̿
  integer :: IWS  ! dcl νϥǥХ
  real :: lon_min  ! ׻ΰü [degree]
  real :: lat_min  ! ׻ΰü [degree]
  real :: dlon  ! γʻҴֳ [degree]
  real :: dlat  ! γʻҴֳ [degree]
  character(80) :: d2valc  ! ɤ߹ѿȽ (2d) [01 ǤȽ]
  character(80) :: d3valc  ! ɤ߹ѿȽ (3d) [01 ǤȽ]
  character(80) :: ad2valc  ! ɤ߹ѿȽ (2dad) [01 ǤȽ]
  character(80) :: ad3valc  ! ɤ߹ѿȽ (3dad) [01 ǤȽ]
  integer, dimension(2) :: nnx  ! ΰüֹ
  integer, dimension(2) :: nny  ! ΰüֹ
  integer, dimension(2) :: nnz  ! ΰξ岼üֹ

  integer :: val2d  ! 2d ѿǿ 1
  integer :: val3d  ! 3d ѿǿ 1
  integer :: val2ad  ! 2d ѿǿ 2
  integer :: val3ad  ! 3d ѿǿ 2

  real :: sfact  ! shade ѿΥեѴ
  real :: cfact  ! contour ѿΥեѴ
  real :: vxfact  ! vector-x ѿΥեѴ
  real :: vyfact  ! vector-y ѿΥեѴ

  namelist /input /nx,ny,nz,xmin,ymin,dx,dy,dt,fnumber,grd_rec,zmin,dz,shade_num,cmin,cmax,contmin,contmax
  namelist /filename /hname,footname,ininame,grdname,title_name
  namelist /file_form /form_typec, form_types
  namelist /dcl_dump /ldump,lwait,lwait1,IWS
  namelist /map_info /lon_min,lat_min,dlon,dlat
  namelist /val_cont /d2valc,d3valc,ad2valc,ad3valc
  namelist /option /nnx,nny,nnz
  namelist /factor /sfact,cfact,vxfact,vyfact

end module

==> libdclaf90-0.40.tar.gz: libdclaf90-0.40/manual/dcl_defval.f90 <==
module dcl_defval  ! DCL ѤΥ͡ꥹѿɬԲķ
  implicit none
!-- namelist values
  integer :: nx  ! ׻ΰ x γʻ
  integer :: ny  ! ׻ΰ y γʻ
  integer :: nz  ! ׻ΰ z γʻ
  real :: xmin  ! x η׻ΰ躸ü [m]
  real :: ymin  ! y η׻ΰü [m]
  real :: zmin  ! z η׻ΰ貼ü [m]
  real :: dx  ! x γʻҴֳ [m]
  real :: dy  ! y γʻҴֳ [m]
  real :: dz  ! z γʻҴֳ [m]
  integer :: dt  ! ׻ֳִ֡ʥץեδֳ֡ [s]
  integer :: fnumber  ! ɤ߹ե
  integer :: grd_rec  ! geography եѿο
  real :: cmin  ! ɤκǾ
  real :: cmax  ! ɤκ
  real :: contmin  ! κǾ
  real :: contmax  ! κ
  character(80) :: hname  ! ץեΥإå
  character(80) :: footname  ! ץեΥեå
  integer :: ininame  ! ץեɤ߹ߤ򳫻Ϥ [׻Ϥ s]
  character(80) :: grdname  ! geography ե̾
  character(80) :: title_name  ! դΥȥ̾ʸźǻ֤Ĥ
  integer :: shade_num  ! ɤʬ
  character(6) :: form_typec  ! Υեޥå
  character(6) :: form_types  ! ɤΥեޥå
  logical :: ldump  ! dcl Υ̿
  logical :: lwait  ! dcl ̿
  logical :: lwait1  ! dcl ̿
  integer :: IWS  ! dcl νϥǥХ
  real :: lon_min  ! ׻ΰü [degree]
  real :: lat_min  ! ׻ΰü [degree]
  real :: dlon  ! γʻҴֳ [degree]
  real :: dlat  ! γʻҴֳ [degree]
  character(80) :: d2valc  ! ɤ߹ѿȽ (2d) [01 ǤȽ]
  character(80) :: d3valc  ! ɤ߹ѿȽ (3d) [01 ǤȽ]
  character(80) :: ad2valc  ! ɤ߹ѿȽ (2dad) [01 ǤȽ]
  character(80) :: ad3valc  ! ɤ߹ѿȽ (3dad) [01 ǤȽ]
  integer, dimension(2) :: nnx  ! ΰüֹ
  integer, dimension(2) :: nny  ! ΰüֹ
  integer, dimension(2) :: nnz  ! ΰξ岼üֹ

  integer :: val2d  ! 2d ѿǿ 1
  integer :: val3d  ! 3d ѿǿ 1
  integer :: val2ad  ! 2d ѿǿ 2
  integer :: val3ad  ! 3d ѿǿ 2

  real :: sfact  ! shade ѿΥեѴ
  real :: cfact  ! contour ѿΥեѴ
  real :: vxfact  ! vector-x ѿΥեѴ
  real :: vyfact  ! vector-y ѿΥեѴ

  integer :: sthopt  ! CReSS namelist
  real :: dzmin  ! CReSS namelist
  real :: layer1  ! CReSS namelist
  real :: layer2  ! CReSS namelist

  namelist /input /nx,ny,nz,xmin,ymin,dx,dy,dt,fnumber,grd_rec,zmin,dz,shade_num,cmin,cmax,contmin,contmax
  namelist /filename /hname,footname,ininame,grdname,title_name
  namelist /file_form /form_typec, form_types
  namelist /dcl_dump /ldump,lwait,lwait1,IWS
  namelist /map_info /lon_min,lat_min,dlon,dlat
  namelist /val_cont /d2valc,d3valc,ad2valc,ad3valc
  namelist /option /nnx,nny,nnz
  namelist /factor /sfact,cfact,vxfact,vyfact
  namelist /cress /sthopt,dzmin,layer1,layer2

end module
